@@ -5,7 +5,6 @@
 #' parameters if any.  If there are user-defined initial values only the
 #' parameters not specified by the user are computed.
 #'
-#'
 #' @usage setinitial.ds(ddfobj,width,initial,point)
 #'        sethazard(ddfobj,dmat,width)
 #' @aliases setinitial.ds sethazard
@@ -19,12 +18,14 @@
 #'   \item{shape}{vector of initial shape parameter values}
 #'   \item{adjustment}{vector of initial adjustment function parameter values}
 #' @author Jeff Laake, Dave Miller
+#' @importFrom stats lm
 setinitial.ds <- function(ddfobj,width,initial,point){
 
   ftype <- ddfobj$type
   if(ftype=="unif"){
     initialvalues <- list(scale=NULL,shape=NULL)
   }
+
   dmat <- ddfobj$xmat
   if(point){
     dmat$distance <- sqrt(dmat$distance)
@@ -39,11 +40,12 @@ setinitial.ds <- function(ddfobj,width,initial,point){
                                rep(0,ncol(ddfobj$shape$dm)-1))
     }
     if(ncol(ddfobj$scale$dm)>1){
-      initialvalues$scale <- c(initialvalues$scale,
-                               rep(0,ncol(ddfobj$scale$dm)-1))
+      initialvalues$scale <- lm(eval(parse(text=paste(
+                            "log(distance+width/1000)",ddfobj$scale$formula))),
+                            data=dmat[dmat$detected==1,])$coeff
     }
   }else{
-    # Set scale parameters using Ramsey's approach of linear model 
+    # Set scale parameters using Ramsey's approach of linear model
     # with log(distance)
     if(ftype!="unif"){
       initialvalues <- list(scale=lm(eval(parse(text=paste(
@@ -59,7 +61,7 @@ setinitial.ds <- function(ddfobj,width,initial,point){
 
   # Set initial values for the adjustment term parameters
   if(!is.null(ddfobj$adjustment)){
-    initialvalues$adjustment <- rep(0,length(ddfobj$adjustment$order)) 
+    initialvalues$adjustment <- rep(0,length(ddfobj$adjustment$order))
   }
 
   if(!any(is.na(initial))){
